@@ -10,7 +10,7 @@ try:
 except ImportError:
     logger.error('faker package not found onto python packages, please run : \
     pip install -r requirements.txt  \
-    on the root of the project')
+    on the root of the project', extra=d)
 
 
 class DbConnException(Exception):
